OC.L10N.register(
    "viewer",
    {
    "Viewer" : "뷰어",
    "Simple file viewer with slideshow for media" : "미디어 슬라이드 쇼를 지원하는 간단한 파일 뷰어",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "마지막 휴가 때 찍은 사진과 동영상을 영화처럼 볼 수 있고, Nextcloud에 저장되어 있는 쓰고 있는 소설을 볼 수 있고, 즐겨 찾는 파일을 바로 미리 볼 수 있어서 소장하고 있는 GIF 파일 중 최고를 선정할 수 있으며, 더 많은 기능이 있습니다!",
    "Error loading {name}" : "{name} 불러오기 오류",
    "Your browser does not support the video tag." : "브라우저에서 video 태그를 지원하지 않습니다.",
    "View" : "보기"
},
"nplurals=1; plural=0;");
